-- what happens when you use unsargeable search criteria?

-- check these in Plan Explorer:

SELECT COUNT(*) FROM Sales.SalesOrderHeader 
WHERE YEAR(OrderDate) = 2005 
AND MONTH(OrderDate) = 7;

SELECT COUNT(*) FROM Sales.SalesOrderHeader 
WHERE OrderDate >= '20050701'
  AND OrderDate < '20050801';

GO

-- POP QUIZ: what will this yield?

SELECT DATEPART(y, CURRENT_TIMESTAMP);

--   (A) 2013   (B) 123  (C) 13

-- And what will this yield?

SELECT DATEPART(w, CURRENT_TIMESTAMP);

--   (A) 6    (B) 18    (C) Saturday
GO

SELECT DATEPART(YEAR, CURRENT_TIMESTAMP),
       DATEPART(WEEK, CURRENT_TIMESTAMP);



-- what happens when you try to find the "end" of a period?

DECLARE @start DATETIME, @end DATETIME;

SELECT 
  @start = DATEADD(DAY, DATEDIFF(DAY, 1, CURRENT_TIMESTAMP), 0),
  @end   = DATEADD(MILLISECOND, -3, DATEADD(DAY, 1, @start));

SELECT @start, [Datetime] = @end;

SELECT @start, [Smalldatetime] = CONVERT(SMALLDATETIME, @end);

SELECT @start, [Date] = CONVERT(DATE, @end);

SELECT @start, [Datetime2] = CONVERT(DATETIME2(7), @end);


-- Always use open-ended range.
-- Instead of:

SELECT ... WHERE col BETWEEN @start AND @end;

-- Use:

SELECT ... WHERE col >= @start AND col < DATEADD(DAY, 1, @end);